<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Programski posrednik</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta posredniškega strežnika</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP naslov</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Vrata</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Izbirno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Označite &quot;Uporabi posredniški strežnik&quot; v kontekstualnem meniju zaganjalnika po konfiguriranju</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Shrani</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neveljaven IP naslov</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Neveljavna vrata</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Prekini povezavo</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Shrani</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Prekini povezavo</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Ali res želite izbrisati to konfiguracijo?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Žična povezava %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Dostopna točka</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Brezžična povezava %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE povezava %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nov VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>vrsta VPN </translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Izvozi</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Omrežje</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programski posrednik</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Osebna dostopna točka</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Podrobnosti omrežja</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistemski posredniški strežnik</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Ožičeno omrežje</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Brezžično omrežje</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Žični omrežni vmesnik</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Dodaj omrežno povezavo</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Brezžični omrežni vmesnik</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Povezava na skrito omrežje</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Ustvari povezavo PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Ustvari VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Uvozi VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta posredniškega strežnika</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfiguracija URL-ja</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP naslov</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Vrata</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Dostopna točka</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Ustvari dostopno točko</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Vmesnik</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Pas</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Prednostni DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Omrežna maska</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Predpona</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hitrost</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Neveljaven naslov DNS</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Brez vezave</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC naslov naprave</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Podvojen MAC naslov</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Prilagojen MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>To ime že obstaja</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Samodejno povezovanje</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Dostopna točka</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Dodaj nastavitve</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Ustvari dostopno točko</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP naslov</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neveljaven IP naslov</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Neveljavna omrežna maska</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Omrežna maska</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neveljaven IP naslov</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Predpona</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ročno</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Prezri</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP naslov</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Uporabljeno le v ustreznih sredstvih</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Omrežna maska</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Predpona</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neveljaven IP naslov</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Neveljavna omrežna maska</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Omrežje</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP spor</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ročno</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Prezri</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Podrobnosti omrežja</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistemski posredniški strežnik</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programski posrednik</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Podrobnosti omrežja</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Omrežje</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP spor</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Onemogočeno</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ročno</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Nastavi z Upravljalnikom omrežja</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Osebna dostopna točka</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Storitev</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Zavrni EAP overitev</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Zavrni PAP overitev</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Zavrni CHAP overitev</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Zavrni MSCHAP overitev</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Zavrni MSCHAPv2 overitev</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Brez BSD stiskanja podatkov</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Brez Deflate stiskanja podatkov</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Brez stiskanja TCP glave</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Brez stiskanja polja Protocol</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Brez stiskanja naslova/kontrole</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Pošlji PPP Echo pakete</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Uporabite MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bitni MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Ustvari povezavo PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Sistemski posredniški strežnik</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Shrani</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta posredniškega strežnika</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ročno</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Izbirno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Vrata</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP posrednik</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS posrednik</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP posrednik</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS posrednik</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Prezri nastavitve posredniških strežnikov za zgornje gostitelje in domene</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL konfiguracije</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Varnost</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>HITRO</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelirani TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Zaščiten EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Shrani geslo za tega uporabnika</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Shrani gesla za vse uporabnike</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Vedno vprašaj</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Onemogočeno</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonimen</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Overjen</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Oboje</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Različica 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Različica 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP avt.</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identiteta</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Možnosti gesla</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Zasebni ključ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uporabniški cert.</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonimni ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Rezervacije</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC datoteka</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Notranja avt.</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP različica</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Zasebno geslo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neveljavno geslo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Osebno</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Varnost</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ključ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Zahtevana varnost</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neveljavno geslo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Osebno</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Za podjetja</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Deljeni ključ</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Odprti sistem</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Varnost</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Overitev</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ključ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN napredno</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Nastavi vrata prehoda</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Vrata prehoda</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Nastavi interval za ponovno pogajanje</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interval za ponovno pogajanje</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Uporabi LZO stiskanje podatkov</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Uporabi TCP povezavo</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Uporabi TAP napravo</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Nastavi MTU tunel</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Prilagodi velikost UDP fragmenta</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Velikost UDP fragmenta</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Omeji TCP MSS tunel</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Naključno razporedi oddaljene gostitelje</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN napredno</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (privzeto)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Varno (privzeto)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Šibko</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T kadar je na voljo (privzeto)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T vedno</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Onemogočeno</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Skupina 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Skupina 2 (privzeto)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Skupina 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Strežnik (privzeto)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Skupina 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domena</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Proizvajalec</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Različica</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifriranje</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Traverzalni NAT način</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Posreduj skrivnost</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokalna vrata</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Onemogoči zaznavanje nedelujočih soležnikov</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Omogoči IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Ime skupine</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID skupine</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Prej-deljeni ključ</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 algoritmi </translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 algoritmi</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Posredniški strežnik</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Dovoli Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD skript</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uporabniški cert.</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Zasebni ključ</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Uporabi FSID za šifrirno geslo ključa</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certifikati (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certifikat z geslom (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statični ključ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Shranjeno</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Vprašaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Neobvezno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Način overitve</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uporabniški cert.</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Zasebni ključ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Možnosti gesla</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Zasebno geslo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Prilagodi smer ključa</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Smer ključa</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Oddaljeni IP </translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokalni IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Vse razpoložljivo (privzeto)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bitni (manj varno)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bitni (najbolj varno)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Zavrni EAP overitev</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Zavrni PAP overitev</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Zavrni CHAP overitev</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Zavrni MSCHAP overitev</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Zavrni MSCHAPv2 overitev</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Brez BSD stiskanja podatkov</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Brez Deflate stiskanja podatkov</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Brez stiskanja TCP glave</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Brez stiskanja polja Protocol</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Brez stiskanja naslova/kontrole</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Pošlji PPP Echo pakete</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Uporabite MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Varnost</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Ustvari VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Uvozi VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Napak pri uvažanju</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Napaka v datoteki</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN posredniški strežnik</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Neobvezno</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta posredniškega strežnika</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP strežnika</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Vrata</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Ponovno poskušaj dokler ni povezave.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA datoteka</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Prezri opozorila certifikata</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Uporabi razširitve za TLS ime gostitelja</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN varnost</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Šifrant</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC overitev</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Shranjeno</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Vprašaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Neobvezno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Možnosti gesla</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT domena</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN posredniški strežnik</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP strežnika</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Vrata</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Zasebni ključ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Pametna kartica</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Prej-deljeni ključ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Način overitve</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uporabniški cert.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Zahtevaj notranji IP naslov</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Vsili UDP enkapsulacijo</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Uporabi IP stiskanje</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Vklopi lastne predloge šifranta</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS overjanje</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Odjemalec</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Strežnik</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Ujemanje teme</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Vrsta oddaljenega certifikata</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Datoteka s ključem</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Prilagodi smer ključa</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Smer ključa</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neveljaven prehod</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Shranjeno</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Vprašaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Neobvezno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Možnosti gesla</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Ime skupine</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Geslo skupine</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Uporabi hibridno overjanje</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA datoteka</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Najprej priključite omrežni kabel</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Žični omrežni vmesnik</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Dodaj omrežno povezavo</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Izberi nastavitve</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Brezžični omrežni vmesnik</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Zapri dostopno točko</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Izklopite dostopno točko, če se želite povezati z brezžičnim omrežjem</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Poveži se na skrito omrežje</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Brez vezave</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obvezno</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC naslov naprave</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Prilagojen MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Dostopna točka</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Vrsta varnosti</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pas</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Vmesnik</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Omrežna maska</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Prednostni DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Predpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hitrost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Naprava onemogočena</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Povezano, brez dostopa do spleta</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Brez povezave</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Omrežni kabel je izklopljen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezovanje</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Overjanje</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Pridobivanje IP naslova</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Povezava vzpostavljena</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Povezava prekinjena</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP spor</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ni uspelo</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Pridobivanje naslova</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Ožičeno omrežje</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Žično omrežje %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Brezžično omrežje</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Brezžično omrežje %1</translation>
    </message>
</context>
</TS>